@@ -62,6 +62,7 @@ static const gchar *ICON_NAMES[] = { "applications-other", "applications-interne
 
 /* --- globals --- */
 static gboolean opt_create_new = FALSE;
+static gboolean opt_print_saved_uri = FALSE;
 static gboolean opt_version = FALSE;
 static gchar   *opt_type = NULL;
 static gchar   *opt_name = NULL;
@@ -87,6 +88,7 @@ static GOptionEntry option_entries[] =
   { "command", 0, 0, G_OPTION_ARG_STRING, &opt_command, N_ ("Preset command when creating a launcher"), NULL, },
   { "url", 0, 0, G_OPTION_ARG_STRING, &opt_url, N_ ("Preset URL when creating a link"), NULL, },
   { "icon", 0, 0, G_OPTION_ARG_STRING, &opt_icon, N_ ("Preset icon when creating a desktop file"), NULL, },
+  { "print-saved-uri", 0, 0, G_OPTION_ARG_NONE, &opt_print_saved_uri, N_ ("Print the final saved URI after creating or editing the file"), NULL, },
   { "version", 'V', 0, G_OPTION_ARG_NONE, &opt_version, N_ ("Print version information and exit"), NULL, },
   { "xid", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_INT64, &opt_xid, NULL, NULL, },
   { NULL, },
@@ -156,7 +158,9 @@ main (int argc, char **argv)
   gchar          **dirs;
   guint            i;
   const gchar     *mode_dir;
-  gint             ox, oy, ow, oh;
+  GFile           *result_file = NULL;
+
+  g_warning ("exo-desktop-item-edit is deprecated, use xfce-desktop-item-edit from libxfce4ui >= 4.21.0 instead");
 
   /* setup translation domain */
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
@@ -193,10 +197,13 @@ main (int argc, char **argv)
   if (G_UNLIKELY (opt_version))
     {
       g_print ("%s %s\n\n", g_get_prgname (), PACKAGE_VERSION);
-      g_print (_("Copyright (c) %s\n"
-                 "        os-cillation e.K. All rights reserved.\n\n"
-                 "Written by Benedikt Meurer <benny@xfce.org>.\n\n"),
-               "2005-2007");
+
+      g_print ("%s\n", "Copyright (c) 2005-2007");
+      g_print ("\t%s\n\n", _("os-cillation e.K. All rights reserved."));
+      g_print ("%s\n", "Copyright (c) 2008-2025");
+      g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
+
+      g_print ("%s\n\n",_("Written by Benedikt Meurer <benny@xfce.org>."));
       g_print (_("%s comes with ABSOLUTELY NO WARRANTY,\n"
                  "You may redistribute copies of %s under the terms of\n"
                  "the GNU Lesser General Public License which can be found in the\n"
@@ -328,7 +335,9 @@ main (int argc, char **argv)
   g_signal_connect (G_OBJECT (dialog), "response",
                     G_CALLBACK (exo_die_response_cb), dialog);
 
+#if !LIBXFCE4UI_CHECK_VERSION (4, 19, 3)
   xfce_titled_dialog_create_action_area (XFCE_TITLED_DIALOG (dialog));
+#endif
 
   /* add the "Help" button */
   button = gtk_button_new_with_mnemonic (_("_Help"));
@@ -429,8 +438,10 @@ main (int argc, char **argv)
 
   /* check if a parent window id was specified */
 #if defined(GDK_WINDOWING_X11)
-  if (G_UNLIKELY (opt_xid != 0))
+  if (G_UNLIKELY (opt_xid != 0 && GDK_IS_X11_DISPLAY (gdk_display_get_default ())))
     {
+      gint ox, oy, ow, oh;
+
       /* try to determine the window for the id */
       xwindow = gdk_x11_window_foreign_new_for_display (gdk_display_get_default(), opt_xid);
       if (G_LIKELY (xwindow != NULL))
@@ -515,7 +526,8 @@ main (int argc, char **argv)
         }
 
       /* try to save the file */
-      if (!exo_die_g_key_file_save (key_file, opt_create_new, trusted_launcher, gfile, mode, &error))
+      result_file = exo_die_g_key_file_save (key_file, opt_create_new, trusted_launcher, gfile, mode, &error);
+      if (result_file == NULL)
         {
           if (opt_create_new)
             {
@@ -564,7 +576,7 @@ main (int argc, char **argv)
 
                   /* try again to save to the new file */
                   gfile = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (chooser));
-                  exo_die_g_key_file_save (key_file, FALSE, trusted_launcher, gfile, mode, &error);
+                  result_file = exo_die_g_key_file_save (key_file, FALSE, trusted_launcher, gfile, mode, &error);
                 }
 
               /* destroy the chooser */
@@ -584,7 +596,7 @@ main (int argc, char **argv)
 
                   g_clear_error (&error);
 
-                  exo_die_g_key_file_save (key_file, FALSE, trusted_launcher, gfile_local, mode, &error);
+                  result_file = exo_die_g_key_file_save (key_file, FALSE, trusted_launcher, gfile_local, mode, &error);
                   g_object_unref (gfile_local);
                 }
             }
@@ -629,7 +641,7 @@ main (int argc, char **argv)
 
                       /* try another save */
                       gfile_local = g_file_new_for_path (path);
-                      exo_die_g_key_file_save (key_file, FALSE, trusted_launcher, gfile_local, mode, &error);
+                      result_file = exo_die_g_key_file_save (key_file, FALSE, trusted_launcher, gfile_local, mode, &error);
                       g_object_unref (G_OBJECT (gfile_local));
                     }
 
@@ -674,5 +686,17 @@ main (int argc, char **argv)
   g_key_file_free (key_file);
   g_object_unref (G_OBJECT (gfile));
 
+  if (result == EXIT_SUCCESS && result_file != NULL && opt_print_saved_uri)
+    {
+      gchar *uri = g_file_get_uri (result_file);
+      g_print ("%s\n", uri);
+      g_free (uri);
+    }
+
+  if (result_file != NULL)
+    {
+      g_object_unref (result_file);
+    }
+
   return result;
 }
