@@ -593,15 +593,16 @@ exo_open_uri (const gchar  *uri,
   g_free (scheme);
 
   if (!retval && error != NULL)
-    *error = err;
+    {
+      g_error_free (*error);
+      *error = err;
+    }
   else if (err != NULL)
     g_error_free (err);
 
   return retval;
 }
 
-#include <gdk/gdkx.h>
-
 gint
 main (gint argc, gchar **argv)
 {
@@ -616,6 +617,8 @@ main (gint argc, gchar **argv)
   guint            i;
   gchar           *uri;
 
+  g_warning ("exo-open is deprecated, use xfce-open from libxfce4ui >= 4.21.0 instead");
+
 #ifdef GETTEXT_PACKAGE
   /* setup i18n support */
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
@@ -636,8 +639,10 @@ main (gint argc, gchar **argv)
     {
       g_fprintf (stderr, "exo-open: %s.\n", err->message);
       g_error_free (err);
+      g_option_context_free (context);
       return EXIT_FAILURE;
     }
+  g_option_context_free (context);
 
   /* restore the startup-id for the child environment */
   if (startup_id != NULL)
@@ -764,10 +769,13 @@ main (gint argc, gchar **argv)
   else if (G_UNLIKELY (opt_version))
     {
       g_print ("%s %s\n\n", g_get_prgname (), PACKAGE_VERSION);
-      g_print (_("Copyright (c) %s\n"
-                 "        os-cillation e.K. All rights reserved.\n\n"
-                 "Written by Benedikt Meurer <benny@xfce.org>.\n\n"),
-               "2005-2007");
+      g_print ("%s\n", "Copyright (c) 2005-2007");
+      g_print ("\t%s\n\n", _("os-cillation e.K. All rights reserved."));
+      g_print ("%s\n", "Copyright (c) 2009-2025");
+      g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
+
+      g_print ("%s\n\n",_("Written by Benedikt Meurer <benny@xfce.org>."));
+
       g_print (_("%s comes with ABSOLUTELY NO WARRANTY,\n"
                  "You may redistribute copies of %s under the terms of\n"
                  "the GNU Lesser General Public License which can be found in the\n"
