@@ -30,18 +30,27 @@
 
 G_BEGIN_DECLS
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-void      exo_gtk_object_destroy_later                (GtkWidget      *object);
-#else
-void      exo_gtk_object_destroy_later                (GtkObject      *object);
-#endif
+G_DEPRECATED
+void        exo_gtk_object_destroy_later                (GtkWidget      *object);
 
-void      exo_gtk_file_chooser_add_thumbnail_preview  (GtkFileChooser *chooser);
+G_DEPRECATED_FOR (xfce_gtk_file_chooser_add_thumbnail_preview)
+void        exo_gtk_file_chooser_add_thumbnail_preview  (GtkFileChooser *chooser);
 
-void      exo_gtk_url_about_dialog_hook               (GtkAboutDialog *about_dialog,
-                                                       const gchar    *address,
-                                                       gpointer        user_data);
+G_DEPRECATED_FOR (xfce_gtk_url_about_dialog_hook)
+void        exo_gtk_url_about_dialog_hook               (GtkAboutDialog *about_dialog,
+                                                         const gchar    *address,
+                                                         gpointer        user_data);
 
+G_DEPRECATED_FOR (xfce_gtk_dialog_get_action_area)
+GtkWidget * exo_gtk_dialog_get_action_area              (GtkDialog *dialog);
+
+G_DEPRECATED
+void        exo_gtk_dialog_add_secondary_button         (GtkDialog *dialog,
+                                                         GtkWidget *button);
+G_DEPRECATED
+void        exo_gtk_position_search_box                 (GtkWidget *view,
+                                                         GtkWidget *search_dialog,
+                                                         gpointer   user_data);
 G_END_DECLS
 
 #endif /* !__EXO_GTK_EXTENSIONS_H__ */
