@@ -160,6 +160,8 @@ exo_tree_view_class_init (ExoTreeViewClass *klass)
    * double click.
    *
    * Since: 0.3.1.3
+   *
+   * Deprecated: 4.21.0.
    **/
   g_object_class_install_property (gobject_class,
                                    PROP_SINGLE_CLICK,
@@ -177,6 +179,8 @@ exo_tree_view_class_init (ExoTreeViewClass *klass)
    * in single-click mode. A value of %0 disables the automatic selection.
    *
    * Since: 0.3.1.5
+   *
+   * Deprecated: 4.21.0.
    **/
   g_object_class_install_property (gobject_class,
                                    PROP_SINGLE_CLICK_TIMEOUT,
@@ -690,13 +694,17 @@ exo_tree_view_single_click_timeout (gpointer user_data)
               gtk_tree_view_set_cursor (GTK_TREE_VIEW (tree_view), tree_view->priv->hover_path, cursor_column, FALSE);
             }
           else if ((tree_view->priv->single_click_timeout_state & GDK_SHIFT_MASK) != 0
-                && gtk_tree_selection_get_mode (selection) == GTK_SELECTION_MULTIPLE)
+                   && gtk_tree_selection_get_mode (selection) == GTK_SELECTION_MULTIPLE)
             {
               /* check if the item is not already selected (otherwise do nothing) */
               if (!gtk_tree_selection_path_is_selected (selection, tree_view->priv->hover_path))
                 {
-                  /* unselect all previously selected items */
-                  gtk_tree_selection_unselect_all (selection);
+                  /* skip if control is being pressed */
+                  if ((tree_view->priv->single_click_timeout_state & GDK_CONTROL_MASK) == 0)
+                    {
+                      /* unselect all previously selected items */
+                      gtk_tree_selection_unselect_all (selection);
+                    }
 
                   /* since we cannot access the anchor of a GtkTreeView, we
                    * use the cursor instead which is usually the same row.
@@ -717,6 +725,7 @@ exo_tree_view_single_click_timeout (gpointer user_data)
             {
               /* check if the hover path is selected (as it will be selected after the set_cursor() call) */
               hover_path_selected = gtk_tree_selection_path_is_selected (selection, tree_view->priv->hover_path);
+
               /* disable selection updates if the path is still selected */
               gtk_tree_selection_set_select_function (selection, select_false, NULL, NULL);
 
@@ -774,6 +783,8 @@ exo_tree_view_single_click_timeout_destroy (gpointer user_data)
  * Returns: the newly allocated #ExoTreeView.
  *
  * Since: 0.3.1.3
+ *
+ * Deprecated: 4.21.0: Use xfce_tree_view_new() instead.
  **/
 GtkWidget*
 exo_tree_view_new (void)
@@ -792,6 +803,8 @@ exo_tree_view_new (void)
  * Returns: whether @tree_view is in single-click mode.
  *
  * Since: 0.3.1.3
+ *
+ * Deprecated: 4.21.0: Use xfce_tree_view_get_single_click() instead.
  **/
 gboolean
 exo_tree_view_get_single_click (const ExoTreeView *tree_view)
@@ -811,6 +824,8 @@ exo_tree_view_get_single_click (const ExoTreeView *tree_view)
  * the default double-click mode will be used.
  *
  * Since: 0.3.1.3
+ *
+ * Deprecated: 4.21.0: Use xfce_tree_view_set_single_click() instead.
  **/
 void
 exo_tree_view_set_single_click (ExoTreeView *tree_view,
@@ -840,6 +855,8 @@ exo_tree_view_set_single_click (ExoTreeView *tree_view,
  *               the behavior is disabled.
  *
  * Since: 0.3.1.5
+ *
+ * Deprecated: 4.21.0: Use xfce_tree_view_get_single_click_timeout() instead.
  **/
 guint
 exo_tree_view_get_single_click_timeout (const ExoTreeView *tree_view)
@@ -865,6 +882,8 @@ exo_tree_view_get_single_click_timeout (const ExoTreeView *tree_view)
  * single-click mode, see exo_tree_view_set_single_click().
  *
  * Since: 0.3.1.5
+ *
+ * Deprecated: 4.21.0: Use xfce_tree_view_set_single_click_timeout() instead.
  **/
 void
 exo_tree_view_set_single_click_timeout (ExoTreeView *tree_view,
